@@ -1,5 +1,5 @@
 package Net::Twitter::Lite;
-our $VERSION = '0.12005';
+our $VERSION = '0.12006';
 use 5.005;
 use warnings;
 use strict;
@@ -10,7 +10,7 @@ Net::Twitter::Lite - A perl library for Twitter's API v1
 
 =head1 VERSION
 
-version 0.12005
+version 0.12006
 
 =cut
 
@@ -20,6 +20,7 @@ use JSON;
 use HTTP::Request::Common;
 use Net::Twitter::Lite::Error;
 use Encode qw/encode_utf8/;
+use Net::Twitter::Lite::WrapResult;
 
 sub twitter_api_def_from           () { 'Net::Twitter::Lite::API::V1' }
 sub _default_api_url               () { 'http://api.twitter.com/1'    }
@@ -576,7 +577,12 @@ sub _parse_result {
         die Net::Twitter::Lite::Error->new(twitter_error => $obj, http_response => $res);
     }
 
-    return $obj if $res->is_success && defined $obj;
+    if ( $res->is_success && defined $obj ) {
+        if ( $self->{wrap_result} ) {
+            $obj = Net::Twitter::Lite::WrapResult->new($obj, $res);
+        }
+        return $obj;
+    }
 
     my $error = Net::Twitter::Lite::Error->new(http_response => $res);
     $error->twitter_error($obj) if ref $obj;
